@@ -1,6 +1,6 @@
 use super::{
-    constants, extensions::Extensions, file::FileAttrs, seq_iter::SeqIter, visitor::impl_visitor,
-    HandleOwned,
+    constants, extensions::Extensions, file_attrs::FileAttrs, seq_iter::SeqIter,
+    visitor::impl_visitor, HandleOwned,
 };
 
 use serde::de::{Deserializer, Error, Unexpected};
@@ -65,23 +65,11 @@ pub struct Response {
 }
 
 impl Response {
-    /// * `packet_len` - total length of the packet, MUST NOT include the packet_type.
-    ///
-    /// Return Some(header_len) where header_len does not include
-    /// the packet_type.
-    /// Length of the body equals to packet_len - header_len.
-    ///
-    /// Return None if packet_type is invalid
-    pub fn len_of_header(packet_len: usize, packet_type: u8) -> Option<usize> {
-        use constants::*;
-
-        match packet_type {
-            SSH_FXP_STATUS | SSH_FXP_HANDLE | SSH_FXP_NAME | SSH_FXP_ATTRS => Some(packet_len),
-
-            SSH_FXP_DATA => Some(4),
-
-            _ => None,
-        }
+    /// Return Some(true) if the packet is data,
+    /// Some(false) if not,
+    /// None if it isn't a valid response.
+    pub fn is_data(packet_type: u8) -> bool {
+        packet_type == constants::SSH_FXP_DATA
     }
 }
 
